# API

## Preprocessing

```{eval-rst}
.. module:: STutils.pp
.. currentmodule:: STutils

.. autosummary::
    :toctree: generated

    pp.merge_big_cell
```

## Tools

```{eval-rst}
.. module:: STutils.tl
.. currentmodule:: STutils

.. autosummary::
    :toctree: generated

    tl.aucell
    tl.getDEG
    tl.removeBiasGenes
    tl.nhood_enrichment
```

## Plotting

```{eval-rst}
.. module:: STutils.pl
.. currentmodule:: STutils

.. autosummary::
    :toctree: generated

    pl.plot_cellbin_gradient
    pl.plot_cellbin_discrete
    pl.getDefaultColors
    pl.nhood_heatmap
```
